/*
 *  $Id: lightvisualizatorextension.h 4555 2012-01-17 10:03:03Z tovar $
 *  Proyecto Ginkgo
 *
 *  Copyright 2008 MetaEmotion S.L. All rights reserved.
 *
 */
#pragma once
#include <prvext/prvext.h>

#include <wx/dynlib.h>
#include <api/imodulo.h>

/*
* This class implements extension's library interface
*/
class LightVisualizatorExtension: public PrivateExtension
{
public :
	LightVisualizatorExtension();
	~LightVisualizatorExtension();
	//here you have to return module controller of this extension
	virtual TListControllers InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
	//it's used by Ginkgo CADx core to know if extension is activated or not, extension can implement it's own security policies
	virtual bool IsActivated();
	//it's used by Ginkgo CADx core to show library activation dialog
	virtual void ShowActivationDialog(wxWindow* pParent);
};

